@@ -4,7 +4,7 @@
 
     config_setup_boxlayout.cc - this file is part of Gerbera.
 
-    Copyright (C) 2023-2025 Gerbera Contributors
+    Copyright (C) 2023-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -41,8 +41,21 @@
 #include "util/logger.h"
 
 #include <algorithm>
+#include <array>
 #include <numeric>
 
+ConfigBoxLayoutSetup::ConfigBoxLayoutSetup(
+    ConfigVal option,
+    const char* xpath,
+    const char* help,
+    std::vector<BoxLayout> defaultEntries)
+    : ConfigSetup(option, xpath, help)
+    , defaultEntries(std::move(defaultEntries))
+{
+}
+
+ConfigBoxLayoutSetup::~ConfigBoxLayoutSetup() = default;
+
 /// @brief Creates an array of BoxLayout objects from a XML nodeset.
 /// @param element starting element of the nodeset.
 bool ConfigBoxLayoutSetup::createOptionFromNode(
@@ -74,12 +87,12 @@ bool ConfigBoxLayoutSetup::createOptionFromNode(
     auto&& boxcs = definition->findConfigSetup<ConfigSetup>(ConfigVal::A_BOXLAYOUT_BOX);
     auto&& chaincs = definition->findConfigSetup<ConfigSetup>(ConfigVal::A_BOXLAYOUT_CHAIN);
     for (auto&& itBox : listcs->getXmlTree(element)) {
-        const pugi::xml_node& childBox = itBox.node();
+        auto childBox = itBox.node();
         if (config) {
             config->registerNode(childBox.path());
         }
         for (auto&& it : boxcs->getXmlTree(childBox)) {
-            const pugi::xml_node& child = it.node();
+            auto child = it.node();
             if (config) {
                 config->registerNode(child.path());
             }
@@ -111,7 +124,7 @@ bool ConfigBoxLayoutSetup::createOptionFromNode(
         }
         std::size_t index = 0;
         for (auto&& it : chaincs->getXmlTree(childBox)) {
-            const pugi::xml_node& child = it.node();
+            auto child = it.node();
             if (config) {
                 config->registerNode(child.path());
             }
@@ -338,7 +351,7 @@ bool ConfigBoxLayoutSetup::updateItem(
 
     // Links vector key
     {
-        auto keyIndex = getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, linkKey.data());
+        auto keyIndex = getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, linkKey);
         if (optItem == keyIndex) {
             std::size_t j = indexList.at(1);
             std::size_t k = indexList.at(2);
@@ -355,7 +368,7 @@ bool ConfigBoxLayoutSetup::updateItem(
     }
     // Links vector value
     {
-        auto valIndex = getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, linkValue.data());
+        auto valIndex = getItemPath(indexList, { ConfigVal::A_BOXLAYOUT_CHAIN, ConfigVal::A_BOXLAYOUT_CHAIN_LINKS, ConfigVal::A_BOXLAYOUT_CHAIN_LINK }, linkValue);
         if (optItem == valIndex) {
             std::size_t j = indexList.at(1);
             std::size_t k = indexList.at(2);
