@@ -3,7 +3,7 @@
 
   sql_format.h - this file is part of Gerbera.
 
-  Copyright (C) 2021-2024 Gerbera Contributors
+  Copyright (C) 2021-2026 Gerbera Contributors
 
   Gerbera is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
@@ -20,12 +20,15 @@
   $Id$
 */
 
-/// \file sql_format.h
+/// @file database/sql_format.h
 
 #ifndef __SQL_FORMAT_H__
 #define __SQL_FORMAT_H__
 
 #include <fmt/format.h>
+#if FMT_VERSION >= 100202
+#include <fmt/ranges.h>
+#endif
 
 struct SQLIdentifier {
     SQLIdentifier(std::string name, char quote_begin, char quote_end)
@@ -39,32 +42,16 @@ struct SQLIdentifier {
     char quote_end;
 };
 
+namespace fmt {
+
 template <>
-struct fmt::formatter<SQLIdentifier> : formatter<std::string> {
+struct formatter<SQLIdentifier> : formatter<std::string> {
     template <typename FormatContext>
     auto format(const SQLIdentifier& tn, FormatContext& ctx) const -> decltype(ctx.out())
     {
         return format_to(ctx.out(), "{}{}{}", tn.quote_begin, tn.name, tn.quote_end);
     }
 };
-
-struct ColumnUpdate {
-    ColumnUpdate(SQLIdentifier column, std::string value)
-        : column(std::move(column))
-        , value(std::move(value))
-    {
-    }
-    SQLIdentifier column;
-    std::string value;
-};
-
-template <>
-struct fmt::formatter<ColumnUpdate> : formatter<std::string> {
-    template <typename FormatContext>
-    auto format(const ColumnUpdate& a, FormatContext& ctx) const -> decltype(ctx.out())
-    {
-        return format_to(ctx.out(), "{} = {}", a.column, a.value);
-    }
 };
 
 #endif
