@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -76,6 +76,13 @@ bool Web::Containers::processPageAction(Json::Value& element, const std::string&
             ce["image"] = url.value();
         }
 
+#ifdef HAVE_ZIP
+        auto zip = xmlBuilder->renderContainerZipURL(cont);
+        if (zip) {
+            ce["zip"] = zip.value();
+        }
+#endif
+
         auto autoscanType = cont->getAutoscanType();
         std::string autoscanMode = (autoscanType != AutoscanType::None) ? AUTOSCAN_TIMED : "none";
         auto adir = content->getAutoscanDirectory(cont->getLocation());
@@ -91,7 +98,7 @@ bool Web::Containers::processPageAction(Json::Value& element, const std::string&
             }
         }
 #endif
-        ce["autoscan_type"] = mapAutoscanType(autoscanType).data();
+        ce["autoscan_type"] = mapAutoscanType(autoscanType);
         ce["autoscan_mode"] = autoscanMode;
         ce["persistent"] = cont->getFlags() & OBJECT_FLAG_PERSISTENT_CONTAINER ? true : false;
         ce["title"] = cont->getTitle();
