@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -99,7 +99,7 @@ protected:
     virtual std::string_view getPage() const = 0;
 
     /// @brief Convert Autoscan type to string representation
-    static std::string_view mapAutoscanType(AutoscanType type);
+    static std::string mapAutoscanType(AutoscanType type);
 
 public:
     /// @brief Constructor
